@@ -6,12 +6,13 @@
 
 set -e
 
-source $(dirname $0)/../set-ver-prms.sh "$1" "$2"
+DIR=$(readlink -f $(dirname $0))
+source $DIR/../set-ver-prms.sh "$1" "$2"
 
 if [[ -n "$3" ]]; then
-	SRC_DIR=$3
+	SRC_DIR=$(readlink -f $3)
 else
-	SRC_DIR=$(readlink -f $(dirname $0)/../..)
+	SRC_DIR=$(readlink -f $DIR/../..)
 fi
 
 PARALLEL_PRMS="-j$(nproc)"
@@ -22,7 +23,12 @@ pushd build/appimage-x86_64
 rm -rf *
 export LANG=C
 
-GO_PRMS="-DCMAKE_INSTALL_PREFIX=/usr -DRTAUDIO_USE_JACK=OFF -DRTMIDI_USE_JACK=OFF -DGO_USE_JACK=OFF -DCMAKE_BUILD_TYPE=Release $CMAKE_VERSION_PRMS"
+GO_PRMS="-DCMAKE_INSTALL_PREFIX=/usr \
+  -DRTAUDIO_USE_JACK=OFF \
+  -DRTMIDI_USE_JACK=OFF \
+  -DGO_USE_JACK=OFF \
+  -DCMAKE_BUILD_TYPE=Release \
+  $CMAKE_VERSION_PRMS"
 echo "cmake -G \"Unix Makefiles\" $GO_PRMS . $SRC_DIR"
 cmake -G "Unix Makefiles" $GO_PRMS . $SRC_DIR
 make -k $PARALLEL_PRMS
