@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -8,6 +8,9 @@
 #ifndef GOCONFIGREADER_H
 #define GOCONFIGREADER_H
 
+#include <unordered_set>
+
+#include <wx/hashmap.h>
 #include <wx/string.h>
 
 #include "GOLogicalColour.h"
@@ -23,8 +26,12 @@ typedef enum { ODFSetting, CMBSetting } GOSettingType;
 
 class GOConfigReader {
 private:
-  bool m_Strict;
+  using StringSet = std::unordered_set<wxString, wxStringHash, wxStringEqual>;
+
   GOConfigReaderDB &m_Config;
+  StringSet m_GroupsInUse;
+  bool m_Strict;
+  bool m_IsHw1Check;
 
   bool Read(
     GOSettingType type,
@@ -34,7 +41,8 @@ private:
     wxString &value);
 
 public:
-  GOConfigReader(GOConfigReaderDB &cfg, bool strict = true);
+  GOConfigReader(
+    GOConfigReaderDB &cfg, bool strict = true, bool hw1Check = false);
 
   /**
    * Reads a triple-value boolean (-1 - not defined, 0 - false, 1 - true)
@@ -167,6 +175,13 @@ public:
     unsigned count,
     bool required,
     int defaultValue);
+
+  /**
+   * Mark the group as used. Throws an exception if the group has already been
+   * marked as in use
+   * @param group the group name
+   */
+  void MarkGroupInUse(const wxString &group);
 };
 
 #endif
