@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -49,7 +49,7 @@ GOAudioRecorder::GOAudioRecorder(GOOrganController *organController)
     m_RecordSeconds(0),
     m_Filename(),
     m_DoRename(false) {
-  CreateButtons(m_OrganController);
+  CreateButtons(*m_OrganController);
   UpdateDisplay();
 }
 
@@ -70,7 +70,7 @@ void GOAudioRecorder::Load(GOConfigReader &cfg) {
   m_RecordingTime.Init(cfg, wxT("AudioRecordTime"), _("Audio recording time"));
 }
 
-void GOAudioRecorder::ButtonStateChanged(int id) {
+void GOAudioRecorder::ButtonStateChanged(int id, bool newState) {
   switch (id) {
   case ID_AUDIO_RECORDER_STOP:
     StopRecording();
