@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,9 +10,10 @@
 
 #include <wx/string.h>
 
-#include "GOBitmap.h"
 #include "ptrvector.h"
 
+#include "gui/primitives/GOBitmap.h"
+
 class GOOrganController;
 
 class GOBitmapCache {
