@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -57,7 +57,7 @@ GOMetronome::GOMetronome(GOOrganController *organController)
     m_MeasureDisplay(organController),
     m_rank(NULL),
     m_StopID(0) {
-  CreateButtons(m_OrganController);
+  CreateButtons(*m_OrganController);
 
   m_buttons[ID_METRONOME_ON]->SetPreconfigIndex(25);
   m_buttons[ID_METRONOME_MEASURE_P1]->SetPreconfigIndex(28);
@@ -65,7 +65,7 @@ GOMetronome::GOMetronome(GOOrganController *organController)
   m_buttons[ID_METRONOME_BEAT_P1]->SetPreconfigIndex(26);
   m_buttons[ID_METRONOME_BEAT_M1]->SetPreconfigIndex(27);
 
-  m_OrganController->RegisterPlaybackStateHandler(this);
+  m_OrganController->RegisterSoundStateHandler(this);
 }
 
 GOMetronome::~GOMetronome() { StopTimer(); }
@@ -102,23 +102,23 @@ void GOMetronome::Load(GOConfigReader &cfg) {
 
   m_OrganController->RegisterSaveableObject(this);
 
-  GOWindchest *windchest = new GOWindchest(m_OrganController);
+  GOWindchest *windchest = new GOWindchest(*m_OrganController);
   windchest->Init(cfg, wxT("MetronomeWindchest"), _("Metronome"));
   unsigned samplegroup = m_OrganController->AddWindchest(windchest);
 
-  m_rank = new GORank(m_OrganController);
+  m_rank = new GORank(*m_OrganController);
   m_rank->Init(cfg, wxT("MetronomSounds"), _("Metronome"), 36, samplegroup);
   m_StopID = m_rank->RegisterStop(NULL);
   m_OrganController->AddRank(m_rank);
 
   GOSoundingPipe *pipe;
   pipe = new GOSoundingPipe(
-    m_OrganController, m_rank, true, samplegroup, 36, 8, 0, 100, 100, false);
+    m_OrganController, m_rank, true, samplegroup, 36, 8, 100, 100, false);
   m_rank->AddPipe(pipe);
   pipe->Init(
     cfg, wxT("MetronomSounds"), wxT("A"), wxT("sounds\\metronome\\beat.wv"));
   pipe = new GOSoundingPipe(
-    m_OrganController, m_rank, true, samplegroup, 37, 8, 0, 100, 100, false);
+    m_OrganController, m_rank, true, samplegroup, 37, 8, 100, 100, false);
   m_rank->AddPipe(pipe);
   pipe->Init(
     cfg,
@@ -132,7 +132,7 @@ void GOMetronome::Save(GOConfigWriter &cfg) {
   cfg.WriteInteger(m_group, wxT("MeasureLength"), m_MeasureLength);
 }
 
-void GOMetronome::ButtonStateChanged(int id) {
+void GOMetronome::ButtonStateChanged(int id, bool newState) {
   switch (id) {
   case ID_METRONOME_ON:
     if (m_Running)
@@ -230,10 +230,6 @@ void GOMetronome::PreparePlayback() {
   UpdateState();
 }
 
-void GOMetronome::StartPlayback() {}
-
-void GOMetronome::PrepareRecording() {}
-
 GOEnclosure *GOMetronome::GetEnclosure(const wxString &name, bool is_panel) {
   return NULL;
 }
