@@ -352,16 +352,15 @@ void GOSetter::Load(GOConfigReader &cfg) {
 
   m_framegeneral.resize(0);
   for (unsigned i = 0; i < FRAME_GENERALS; i++) {
-    m_framegeneral.push_back(new GOGeneralCombination(
-      *m_OrganController, m_OrganController->GetGeneralTemplate(), true));
+    m_framegeneral.push_back(
+      new GOGeneralCombination(*m_OrganController, true));
     buffer.Printf(wxT("FrameGeneral%03d"), i + 1);
     m_framegeneral[i]->Load(cfg, buffer);
   }
 
   m_general.resize(0);
   for (unsigned i = 0; i < GENERALS * GENERAL_BANKS; i++) {
-    m_general.push_back(new GOGeneralCombination(
-      *m_OrganController, m_OrganController->GetGeneralTemplate(), true));
+    m_general.push_back(new GOGeneralCombination(*m_OrganController, true));
     buffer.Printf(wxT("SetterGeneral%03d"), i + 1);
     m_general[i]->Load(cfg, buffer);
   }
@@ -377,8 +376,7 @@ void GOSetter::Load(GOConfigReader &cfg) {
       CMBSetting, buffer, WX_OVERRIDE_MODE, false, defaultAddMode);
   }
   for (unsigned i = 0; i < N_CRESCENDOS * CRESCENDO_STEPS; i++) {
-    m_crescendo.push_back(new GOGeneralCombination(
-      *m_OrganController, m_OrganController->GetGeneralTemplate(), true));
+    m_crescendo.push_back(new GOGeneralCombination(*m_OrganController, true));
     m_CrescendoExtraSets.emplace_back();
     buffer.Printf(
       wxT("SetterCrescendo%d_%03d"),
