@@ -18,7 +18,16 @@ GODivisionalButtonControl::GODivisionalButtonControl(
     r_OrganModel(organModel),
     m_combination(organModel, manualNumber, isSetter) {}
 
-wxString GODivisionalButtonControl::GetMidiType() { return _("Divisional"); };
+const wxString WX_MIDI_TYPE_CODE = wxT("Divisional");
+const wxString WX_MIDI_TYPE = _("Divisional");
+
+const wxString &GODivisionalButtonControl::GetMidiTypeCode() const {
+  return WX_MIDI_TYPE_CODE;
+}
+
+const wxString &GODivisionalButtonControl::GetMidiType() const {
+  return WX_MIDI_TYPE;
+}
 
 void GODivisionalButtonControl::Init(
   GOConfigReader &cfg,
