@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -15,7 +15,7 @@
 
 class GOButtonControl;
 class GOConfigReader;
-class GOOrganController;
+class GOOrganModel;
 class GOEnclosure;
 class GOLabelControl;
 
@@ -33,13 +33,10 @@ protected:
   ptr_vector<GOButtonControl> m_buttons;
 
   virtual const struct ButtonDefinitionEntry *GetButtonDefinitionList() = 0;
-  virtual void ButtonStateChanged(int id) = 0;
-  void CreateButtons(GOOrganController *organController);
+  virtual void ButtonStateChanged(int id, bool newState) = 0;
+  void CreateButtons(GOOrganModel &organModel);
 
 public:
-  GOElementCreator();
-  virtual ~GOElementCreator();
-
   virtual void Load(GOConfigReader &cfg) = 0;
 
   virtual GOEnclosure *GetEnclosure(const wxString &name, bool is_panel) = 0;
@@ -48,7 +45,7 @@ public:
   virtual GOButtonControl *GetButtonControl(
     const wxString &name, bool is_panel);
 
-  void ButtonStateChanged(GOButtonControl *button);
+  void ButtonStateChanged(GOButtonControl *button, bool newState) override;
 };
 
 #endif
