@@ -27,7 +27,8 @@ public:
   void Load(GOConfigReader &cfg, wxString group);
   void Push();
 
-  wxString GetMidiType();
+  const wxString &GetMidiTypeCode() const override;
+  const wxString &GetMidiType() const override;
 };
 
 #endif /* GOPISTON_H */
