@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -10,7 +10,8 @@
 
 #include <vector>
 
-#include "GOBitmap.h"
+#include "primitives/GOBitmap.h"
+
 #include "GOGUIControl.h"
 
 class GOManual;
@@ -29,6 +30,7 @@ private:
   GOManual *m_manual;
   unsigned m_ManualNumber;
   std::vector<KeyInfo> m_Keys;
+  wxPoint m_LeftTop;
 
 public:
   GOGUIManual(GOGUIPanel *panel, GOManual *manual, unsigned manual_number);
