@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -41,7 +41,8 @@ std::unique_ptr<GOOpenedFile> GOLoaderFilename::Open(
     GOArchive *const archive = fileStore.FindArchiveContaining(m_path);
 
     if (!archive)
-      throw _("File is not found in the organ package archives");
+      throw wxString::Format(
+        _("File %s is not found in the organ package archives"), m_path);
     file = archive->OpenFile(m_path);
   } else {
     wxString baseDir;
