@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -13,4 +13,4 @@ GODummyPipe::GODummyPipe(
 
 void GODummyPipe::Load(GOConfigReader &cfg, wxString group, wxString prefix) {}
 
-void GODummyPipe::Change(unsigned velocity, unsigned old_velocity) {}
+void GODummyPipe::VelocityChanged(unsigned velocity, unsigned old_velocity) {}
