@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -27,7 +27,7 @@ private:
   void UpdateHash(GOHash &hash);
   const wxString &GetLoadTitle();
 
-  void Change(unsigned velocity, unsigned old_velocity) override;
+  void VelocityChanged(unsigned velocity, unsigned old_velocity) override;
 
 public:
   GOReferencePipe(GOOrganModel *model, GORank *rank, unsigned midi_key_number);
