@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -16,7 +16,7 @@
 #include "GOPipeWindchestCallback.h"
 
 class GOMemoryPool;
-class GOOrganController;
+class GOOrganModel;
 class GOSoundSampler;
 
 class GOSoundingPipe : public GOPipe,
@@ -24,7 +24,7 @@ class GOSoundingPipe : public GOPipe,
                        private GOPipeUpdateCallback,
                        private GOPipeWindchestCallback {
 private:
-  GOOrganController *m_OrganController;
+  GOOrganModel *p_OrganModel;
   GOSoundSampler *m_Sampler;
   uint64_t m_LastStop;
   int m_Instances;
@@ -42,48 +42,72 @@ private:
   unsigned m_HarmonicNumber;
   unsigned m_LoopCrossfadeLength;
   unsigned m_ReleaseCrossfadeLength;
-  float m_PitchCorrection;
   float m_MinVolume;
   float m_MaxVolume;
+  int m_OdfMidiKeyNumber;
+  float m_OdfMidiPitchFraction;
   int m_SampleMidiKeyNumber;
+  float m_SampleMidiPitchFraction;
   bool m_RetunePipe;
   bool m_IsTemperamentOriginalBased;
   GOSoundProviderWave m_SoundProvider;
   GOPipeConfigNode m_PipeConfigNode;
 
-  void SetOn(unsigned velocity);
-  void SetOff();
-  void Change(unsigned velocity, unsigned old_velocity);
-  GOSoundProvider *GetSoundProvider();
+  // internal functions
+  void LoadAttack(GOConfigReader &cfg, wxString group, wxString prefix);
+  /**
+   * Calculate a pitch offset for manual tuning
+   * @return pitch offset in cents
+   */
+  float GetManualTuningPitchOffset() const;
+  /**
+   * Calculates a pitch offset for retuning from the sample pitch
+   * to the equal temperament
+   * @return pitch offset in cents
+   */
+  float GetAutoTuningPitchOffset() const;
   void Validate();
 
-  void LoadAttack(GOConfigReader &cfg, wxString group, wxString prefix);
-
-  void Initialize();
+  // Callbacks for GOCacheObject
+  const wxString &GetLoadTitle() override { return m_Filename; }
+  void Initialize() override {}
   void LoadData(const GOFileStore &fileStore, GOMemoryPool &pool) override;
   bool LoadCache(GOMemoryPool &pool, GOCache &cache) override;
-  bool SaveCache(GOCacheWriter &cache);
-  void UpdateHash(GOHash &hash);
-  const wxString &GetLoadTitle();
+  bool SaveCache(GOCacheWriter &cache) override;
+  void UpdateHash(GOHash &hash) override;
 
-  void SetTremulant(bool on);
+  // Callbacks from GOPipeConfigNode
+  void UpdateAmplitude() override;
+  void UpdateTuning() override;
+  void UpdateAudioGroup() override;
+  void UpdateReleaseTail() override;
+  void SetTemperament(const GOTemperament &temperament) override;
 
-  void UpdateAmplitude();
-  void UpdateTuning();
-  void UpdateAudioGroup();
+  // Callbacks from the sound engine
+  void PreparePlayback() override;
+  void AbortPlayback() override;
 
-  void AbortPlayback();
-  void PreparePlayback();
+  // Callbacks from the console
+  /**
+   * Called when the tremulant is switched on or off
+   * @param on the new tremulant state
+   */
+  void SetTremulant(bool on) override;
+  /**
+   * Called when the key is just pressed, released or the velocity is changed
+   * @param velocity the velocity of key pressing. 0 means release
+   * @param last_velocity the velocity of the previous key pressing
+   */
+  void VelocityChanged(unsigned velocity, unsigned old_velocity) override;
 
 public:
   GOSoundingPipe(
-    GOOrganController *organController,
+    GOOrganModel *organController,
     GORank *rank,
     bool percussive,
     int sampler_group_id,
     unsigned midi_key_number,
     unsigned harmonic_number,
-    float pitch_correction,
     float min_volume,
     float max_volume,
     bool retune);
@@ -91,7 +115,6 @@ public:
   void Init(
     GOConfigReader &cfg, wxString group, wxString prefix, wxString filename);
   void Load(GOConfigReader &cfg, wxString group, wxString prefix);
-  void SetTemperament(const GOTemperament &temperament);
 };
 
 #endif
