@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -11,6 +11,7 @@
 #include "GOPipeConfig.h"
 #include "GOSaveableObject.h"
 
+class GOConfig;
 class GOOrganModel;
 class GOSampleStatistic;
 class GOStatisticCallback;
@@ -18,6 +19,7 @@ class GOStatisticCallback;
 class GOPipeConfigNode : private GOSaveableObject {
 private:
   GOOrganModel *m_OrganModel;
+  const GOConfig &m_config;
   GOPipeConfigNode *m_parent;
   GOPipeConfig m_PipeConfig;
   GOStatisticCallback *m_StatisticCallback;
@@ -33,6 +35,7 @@ public:
     GOStatisticCallback *statistic);
   virtual ~GOPipeConfigNode();
 
+  GOPipeConfigNode *GetParent() const { return m_parent; }
   void SetParent(GOPipeConfigNode *parent);
   void Init(GOConfigReader &cfg, wxString group, wxString prefix);
   void Load(GOConfigReader &cfg, wxString group, wxString prefix);
@@ -42,12 +45,15 @@ public:
 
   GOPipeConfig &GetPipeConfig();
 
-  void ModifyTuning(float diff);
+  void ModifyManualTuning(float diff);
+  void ModifyAutoTuningCorrection(float diff);
 
   float GetEffectiveAmplitude();
   float GetEffectiveGain();
-  float GetEffectiveTuning();
-  float GetDefaultTuning();
+  float GetEffectivePitchTuning() const;
+  float GetEffectivePitchCorrection() const;
+  float GetEffectiveManualTuning() const;
+  float GetEffectiveAutoTuningCorection() const;
 
   unsigned GetEffectiveDelay();
   wxString GetEffectiveAudioGroup();
@@ -58,7 +64,8 @@ public:
   unsigned GetEffectiveAttackLoad();
   unsigned GetEffectiveReleaseLoad();
   unsigned GetEffectiveChannels();
-  bool GetEffectiveIgnorePitch();
+  bool GetEffectiveIgnorePitch() const;
+  unsigned GetEffectiveReleaseTail() const;
 
   virtual void AddChild(GOPipeConfigNode *node);
   virtual unsigned GetChildCount();
