@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -18,9 +18,10 @@ private:
   std::vector<GOPipeConfigNode *> m_Childs;
   GOPipeUpdateCallback *m_Callback;
 
-  void UpdateAmplitude();
-  void UpdateTuning();
-  void UpdateAudioGroup();
+  void UpdateAmplitude() override;
+  void UpdateTuning() override;
+  void UpdateAudioGroup() override;
+  void UpdateReleaseTail() override;
 
 public:
   GOPipeConfigTreeNode(
