@@ -1,6 +1,6 @@
 /*
  * Copyright 2006 Milan Digital Audio LLC
- * Copyright 2009-2022 GrandOrgue contributors (see AUTHORS)
+ * Copyright 2009-2023 GrandOrgue contributors (see AUTHORS)
  * License GPL-2.0 or later
  * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
  */
@@ -38,6 +38,7 @@ protected:
   float m_Gain;
   float m_Tuning;
   bool m_SampleGroup;
+  unsigned m_ReleaseTail;
   ptr_vector<GOAudioSection> m_Attack;
   std::vector<attack_section_info> m_AttackInfo;
   ptr_vector<GOAudioSection> m_Release;
@@ -68,6 +69,8 @@ public:
 
   float GetTuning() const;
   void SetTuning(float cent);
+  unsigned GetReleaseTail() const { return m_ReleaseTail; }
+  void SetReleaseTail(unsigned releaseTail) { m_ReleaseTail = releaseTail; }
 
   unsigned GetMidiKeyNumber() const;
   float GetMidiPitchFract() const;
