@@ -23,7 +23,7 @@ bool GOSoundReleaseWorkItem::GetRepeat() { return true; }
 void GOSoundReleaseWorkItem::Clear() { m_List.Clear(); }
 
 void GOSoundReleaseWorkItem::Reset() {
-  m_Stop = false;
+  m_Stop.store(false);
   m_Cnt = 0;
   m_WaitCnt = 0;
 }
@@ -38,19 +38,19 @@ void GOSoundReleaseWorkItem::Run(GOSoundThread *pThread) {
     while ((sampler = m_List.Get())) {
       m_Cnt.fetch_add(1);
       m_engine.ProcessRelease(sampler);
-      if (m_Stop && m_Cnt > 10)
+      if (m_Stop.load() && m_Cnt > 10)
         break;
     }
     unsigned wait = m_WaitCnt;
     if (wait < m_AudioGroups.size()) {
       m_AudioGroups[wait]->Finish(false);
-      m_WaitCnt.compare_exchange(wait, wait + 1);
+      m_WaitCnt.compare_exchange_strong(wait, wait + 1);
     }
-  } while (!m_Stop && m_WaitCnt < m_AudioGroups.size());
+  } while (!m_Stop.load() && m_WaitCnt < m_AudioGroups.size());
 }
 
 void GOSoundReleaseWorkItem::Exec() {
-  m_Stop = true;
+  m_Stop.store(true);
   Run();
   GOSoundSampler *sampler;
   while ((sampler = m_List.Get()))
